# Terms

This module contains the building blocks for SQL queries such as fields, tables, and criteria.

::: neopika.terms
    handler: python
    options:
      members: true
      show_root_heading: false
      show_source: true
      heading_level: 2 